A module isn't working 'cause transformers gave an error 'cause you didn't have
have a key or maybe an account as it's a faff to set one up because it does not
work with OAuth and you don't entrust your secrets to a smiling but still shady
site that dares to ask for them or maybe it is because your keepass database is
still stuck inside the phone the one you dropped into the toilet and so here we
sit awaiting an email with a link to click just wishing that researchers were a
tiny bit more thoughtful and a little less naive not listen to an emoji with an
invite to a private site a petty walled garden or have heard of Dr Stallman and
would take on board his warnings as he's almost always right if they had they'd
not gate up their models behind logins that have me kneel and beg for access to
dependencies they gated with errors that are unhelpful because nobody ever sees
them as they only use the gui and for all their learned posturing they can't be
all that technical and care more about their surveys than people forced to fill
them it is process over people but our processes are cattle or at least we wish
they were but they've never heard of devops and rarely open up a terminal as it
consists of senseless walls of text like this and conda put them off I guess it
is slow and unreliable all its options wrong as everyone in dataland prefers to
use the mouse it's 3AM I'm sick of this we've just run out of coffee because an
unnamed smart somebody put the landmine called transformers in this subdepedent
module I needed for my code good at least for them I guess but fashion seems to
never check that yesterdays tomorrows will always work with now or perhaps they
never cared or maybe safety safety safety and whatever sells the padlocks in an
ethics that's all backwards I just need to get this working and get to sleep at
last I don't want you all to hate me I just really care about this code I think
it is important that it works when you import it without it being awkward maybe
send it up it to Brewster who cares about computers all you type to use this is
`shruggingface --help`
